@@ -1,13 +1,8 @@
-/**
- * History:
- * - 2018.03.09 file created, following a restructuring of the previous library.
- */
-
 #ifndef UU_NET_STORES_VERTEXSTORE_H_
 #define UU_NET_STORES_VERTEXSTORE_H_
 
 #include <memory>
-#include "core/datastructures/observers/Observer.hpp"
+#include "core/observers/Observer.hpp"
 #include "objects/Vertex.hpp"
 #include "core/stores/ObjectStore.hpp"
 
@@ -29,9 +24,10 @@ class
 
   public:
 
-    typedef Vertex value_type;
+    typedef const Vertex value_type;
+    typedef const Vertex* get_return_type;
     typedef std::string key_type;
-    typedef core::PtrSortedRandomSet<const Vertex,std::shared_ptr<const Vertex>,core::SharedPtrLT<const Vertex>,core::SharedPtrEQ<const Vertex>>::iterator iterator;
+    typedef core::ObjectStore<Vertex>::iterator iterator;
 
     VertexStore(
     );
@@ -88,6 +84,12 @@ class
         const Vertex* v
     ) const;
 
+    /** Returns true if an object with the input id is present in the collection */
+    bool
+    contains(
+        const std::string& key
+    ) const;
+
     const Vertex*
     get(
         const std::string& key
@@ -119,6 +121,11 @@ class
         const Vertex * v
     );
 
+    bool
+    erase(
+        const std::string& key
+    );
+
     void
     attach(
         core::Observer<const Vertex>* obs
